@@ -14,7 +14,7 @@ import (
 func loadHeterogeneousConfigFromRawJSON(interfaceType, name string, rawJSON json.RawMessage) (proto.Message, error) {
 	fsdef := envimpl.NewDefaultFileSystemDefaultImpl()
 	ctx := envctx.ContextWithEnvironment(context.TODO(), fsdef)
-	if rawJSON == nil || len(rawJSON) == 0 {
+	if len(rawJSON) == 0 {
 		rawJSON = []byte("{}")
 	}
 	return registry.LoadImplementationByAlias(ctx, interfaceType, name, []byte(rawJSON))
